import { Component, Input } from '@angular/core';
import { clamp, isNumber, isPresent, isString, isTrueProperty } from '../../util/util';
import { Range } from './range';
/**
 * @private
 */
export class RangeKnob {
    constructor(range) {
        this.range = range;
        this._upper = false;
    }
    get upper() {
        return this._upper;
    }
    set upper(val) {
        this._upper = isTrueProperty(val);
    }
    get ratio() {
        return this._ratio;
    }
    set ratio(ratio) {
        this._ratio = clamp(0, ratio, 1);
        this._val = this.range.ratioToValue(this._ratio);
        if (this.range.snaps) {
            this._ratio = this.range.valueToRatio(this._val);
        }
    }
    get value() {
        return this._val;
    }
    set value(val) {
        if (isString(val)) {
            val = Math.round(val);
        }
        if (isNumber(val) && !isNaN(val)) {
            this._ratio = this.range.valueToRatio(val);
            this._val = this.range.ratioToValue(this._ratio);
        }
    }
    position() {
        this._x = `${this._ratio * 100}%`;
    }
    ngOnInit() {
        if (isPresent(this.range.value)) {
            // we already have a value
            if (this.range.dualKnobs) {
                // we have a value and there are two knobs
                if (this._upper) {
                    // this is the upper knob
                    this.value = this.range.value.upper;
                }
                else {
                    // this is the lower knob
                    this.value = this.range.value.lower;
                }
            }
            else {
                // we have a value and there is only one knob
                this.value = this.range.value;
            }
        }
        else {
            // we do not have a value so set defaults
            this.ratio = ((this.range.dualKnobs && this.upper) ? 1 : 0);
        }
        this.position();
    }
}
RangeKnob.decorators = [
    { type: Component, args: [{
                selector: '.range-knob-handle',
                template: '<div class="range-pin" *ngIf="range.pin">{{_val}}</div>' +
                    '<div class="range-knob"></div>',
                host: {
                    '[class.range-knob-pressed]': 'pressed',
                    '[class.range-knob-min]': '_val===range.min',
                    '[class.range-knob-max]': '_val===range.max',
                    '[style.left]': '_x',
                    '[attr.aria-valuenow]': '_val',
                    '[attr.aria-valuemin]': 'range.min',
                    '[attr.aria-valuemax]': 'range.max',
                    'role': 'slider',
                    'tabindex': '0'
                }
            },] },
];
/** @nocollapse */
RangeKnob.ctorParameters = [
    { type: Range, },
];
RangeKnob.propDecorators = {
    'upper': [{ type: Input },],
};
//# sourceMappingURL=range-knob.js.map