(function (factory) {
    if (typeof module === 'object' && typeof module.exports === 'object') {
        var v = factory(require, exports); if (v !== undefined) module.exports = v;
    }
    else if (typeof define === 'function' && define.amd) {
        define(["require", "exports", '@angular/core', '../../util/util', './range'], factory);
    }
})(function (require, exports) {
    "use strict";
    var core_1 = require('@angular/core');
    var util_1 = require('../../util/util');
    var range_1 = require('./range');
    /**
     * @private
     */
    var RangeKnob = (function () {
        function RangeKnob(range) {
            this.range = range;
            this._upper = false;
        }
        Object.defineProperty(RangeKnob.prototype, "upper", {
            get: function () {
                return this._upper;
            },
            set: function (val) {
                this._upper = util_1.isTrueProperty(val);
            },
            enumerable: true,
            configurable: true
        });
        Object.defineProperty(RangeKnob.prototype, "ratio", {
            get: function () {
                return this._ratio;
            },
            set: function (ratio) {
                this._ratio = util_1.clamp(0, ratio, 1);
                this._val = this.range.ratioToValue(this._ratio);
                if (this.range.snaps) {
                    this._ratio = this.range.valueToRatio(this._val);
                }
            },
            enumerable: true,
            configurable: true
        });
        Object.defineProperty(RangeKnob.prototype, "value", {
            get: function () {
                return this._val;
            },
            set: function (val) {
                if (util_1.isString(val)) {
                    val = Math.round(val);
                }
                if (util_1.isNumber(val) && !isNaN(val)) {
                    this._ratio = this.range.valueToRatio(val);
                    this._val = this.range.ratioToValue(this._ratio);
                }
            },
            enumerable: true,
            configurable: true
        });
        RangeKnob.prototype.position = function () {
            this._x = this._ratio * 100 + "%";
        };
        RangeKnob.prototype.ngOnInit = function () {
            if (util_1.isPresent(this.range.value)) {
                // we already have a value
                if (this.range.dualKnobs) {
                    // we have a value and there are two knobs
                    if (this._upper) {
                        // this is the upper knob
                        this.value = this.range.value.upper;
                    }
                    else {
                        // this is the lower knob
                        this.value = this.range.value.lower;
                    }
                }
                else {
                    // we have a value and there is only one knob
                    this.value = this.range.value;
                }
            }
            else {
                // we do not have a value so set defaults
                this.ratio = ((this.range.dualKnobs && this.upper) ? 1 : 0);
            }
            this.position();
        };
        RangeKnob.decorators = [
            { type: core_1.Component, args: [{
                        selector: '.range-knob-handle',
                        template: '<div class="range-pin" *ngIf="range.pin">{{_val}}</div>' +
                            '<div class="range-knob"></div>',
                        host: {
                            '[class.range-knob-pressed]': 'pressed',
                            '[class.range-knob-min]': '_val===range.min',
                            '[class.range-knob-max]': '_val===range.max',
                            '[style.left]': '_x',
                            '[attr.aria-valuenow]': '_val',
                            '[attr.aria-valuemin]': 'range.min',
                            '[attr.aria-valuemax]': 'range.max',
                            'role': 'slider',
                            'tabindex': '0'
                        }
                    },] },
        ];
        /** @nocollapse */
        RangeKnob.ctorParameters = [
            { type: range_1.Range, },
        ];
        RangeKnob.propDecorators = {
            'upper': [{ type: core_1.Input },],
        };
        return RangeKnob;
    }());
    exports.RangeKnob = RangeKnob;
});
//# sourceMappingURL=range-knob.js.map